==> tekton-model-triggers-v1alpha1-6.2.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerTemplateSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimBuilder;
import java.lang.Integer;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;

 /**
  * Generated
  */
public interface TriggerTemplateSpecFluent<A extends TriggerTemplateSpecFluent<A>> extends Fluent<A>{
  public A addToParams(Integer index,ParamSpec item);
  public A setToParams(Integer index,ParamSpec item);
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.ParamSpec... items);
  public A addAllToParams(Collection<ParamSpec> items);
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.ParamSpec... items);
  public A removeAllFromParams(Collection<ParamSpec> items);
  public A removeMatchingFromParams(Predicate<ParamSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParamSpec> getParams();
  public List<ParamSpec> buildParams();
  public ParamSpec buildParam(Integer index);
  public ParamSpec buildFirstParam();
  public ParamSpec buildLastParam();
  public ParamSpec buildMatchingParam(Predicate<ParamSpecBuilder> predicate);
  public Boolean hasMatchingParam(Predicate<ParamSpecBuilder> predicate);
  public A withParams(List<ParamSpec> params);
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.ParamSpec... params);
  public Boolean hasParams();
  public A addNewParam(String _default,String description,String name);
  public TriggerTemplateSpecFluent.ParamsNested<A> addNewParam();
  public TriggerTemplateSpecFluent.ParamsNested<A> addNewParamLike(ParamSpec item);
  public TriggerTemplateSpecFluent.ParamsNested<A> setNewParamLike(Integer index,ParamSpec item);
  public TriggerTemplateSpecFluent.ParamsNested<A> editParam(Integer index);
  public TriggerTemplateSpecFluent.ParamsNested<A> editFirstParam();
  public TriggerTemplateSpecFluent.ParamsNested<A> editLastParam();
  public TriggerTemplateSpecFluent.ParamsNested<A> editMatchingParam(Predicate<ParamSpecBuilder> predicate);
  public A addToResourcetemplates(VisitableBuilder<? extends HasMetadata,?> builder);
  public A addToResourcetemplates(Integer index,VisitableBuilder<? extends HasMetadata,?> builder);
  public A addToResourcetemplates(Integer index,HasMetadata item);
  public A setToResourcetemplates(Integer index,HasMetadata item);
  public A addToResourcetemplates(io.fabric8.kubernetes.api.model.HasMetadata... items);
  public A addAllToResourcetemplates(Collection<HasMetadata> items);
  public A removeFromResourcetemplates(VisitableBuilder<? extends HasMetadata,?> builder);
  public A removeFromResourcetemplates(io.fabric8.kubernetes.api.model.HasMetadata... items);
  public A removeAllFromResourcetemplates(Collection<HasMetadata> items);
  
  /**
   * This method has been deprecated, please use method buildResourcetemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HasMetadata> getResourcetemplates();
  public List<HasMetadata> buildResourcetemplates();
  public HasMetadata buildResourcetemplate(Integer index);
  public HasMetadata buildFirstResourcetemplate();
  public HasMetadata buildLastResourcetemplate();
  public HasMetadata buildMatchingResourcetemplate(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public Boolean hasMatchingResourcetemplate(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public A withResourcetemplates(List<HasMetadata> resourcetemplates);
  public A withResourcetemplates(io.fabric8.kubernetes.api.model.HasMetadata... resourcetemplates);
  public Boolean hasResourcetemplates();
  public A addToTriggerTemplateResourcetemplates(Integer index,TriggerTemplate item);
  public A setToTriggerTemplateResourcetemplates(Integer index,TriggerTemplate item);
  public A addToTriggerTemplateResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A addAllToTriggerTemplateResourcetemplates(Collection<TriggerTemplate> items);
  public A removeFromTriggerTemplateResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A removeAllFromTriggerTemplateResourcetemplates(Collection<TriggerTemplate> items);
  public A removeMatchingFromTriggerTemplateResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<A> setNewTriggerTemplateResourcetemplateLike(Integer index,TriggerTemplate item);
  public TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<A> addNewTriggerTemplateResourcetemplate();
  public TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<A> addNewTriggerTemplateResourcetemplateLike(TriggerTemplate item);
  public A addToClusterInterceptorResourcetemplates(Integer index,ClusterInterceptor item);
  public A setToClusterInterceptorResourcetemplates(Integer index,ClusterInterceptor item);
  public A addToClusterInterceptorResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A addAllToClusterInterceptorResourcetemplates(Collection<ClusterInterceptor> items);
  public A removeFromClusterInterceptorResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A removeAllFromClusterInterceptorResourcetemplates(Collection<ClusterInterceptor> items);
  public A removeMatchingFromClusterInterceptorResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<A> setNewClusterInterceptorResourcetemplateLike(Integer index,ClusterInterceptor item);
  public TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<A> addNewClusterInterceptorResourcetemplate();
  public TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<A> addNewClusterInterceptorResourcetemplateLike(ClusterInterceptor item);
  public A addToTriggerBindingResourcetemplates(Integer index,TriggerBinding item);
  public A setToTriggerBindingResourcetemplates(Integer index,TriggerBinding item);
  public A addToTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A addAllToTriggerBindingResourcetemplates(Collection<TriggerBinding> items);
  public A removeFromTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A removeAllFromTriggerBindingResourcetemplates(Collection<TriggerBinding> items);
  public A removeMatchingFromTriggerBindingResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<A> setNewTriggerBindingResourcetemplateLike(Integer index,TriggerBinding item);
  public TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<A> addNewTriggerBindingResourcetemplate();
  public TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<A> addNewTriggerBindingResourcetemplateLike(TriggerBinding item);
  public A addToClusterTriggerBindingResourcetemplates(Integer index,ClusterTriggerBinding item);
  public A setToClusterTriggerBindingResourcetemplates(Integer index,ClusterTriggerBinding item);
  public A addToClusterTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A addAllToClusterTriggerBindingResourcetemplates(Collection<ClusterTriggerBinding> items);
  public A removeFromClusterTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A removeAllFromClusterTriggerBindingResourcetemplates(Collection<ClusterTriggerBinding> items);
  public A removeMatchingFromClusterTriggerBindingResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<A> setNewClusterTriggerBindingResourcetemplateLike(Integer index,ClusterTriggerBinding item);
  public TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<A> addNewClusterTriggerBindingResourcetemplate();
  public TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<A> addNewClusterTriggerBindingResourcetemplateLike(ClusterTriggerBinding item);
  public A addToPersistentVolumeClaimResourcetemplates(Integer index,PersistentVolumeClaim item);
  public A setToPersistentVolumeClaimResourcetemplates(Integer index,PersistentVolumeClaim item);
  public A addToPersistentVolumeClaimResourcetemplates(io.fabric8.kubernetes.api.model.PersistentVolumeClaim... items);
  public A addAllToPersistentVolumeClaimResourcetemplates(Collection<PersistentVolumeClaim> items);
  public A removeFromPersistentVolumeClaimResourcetemplates(io.fabric8.kubernetes.api.model.PersistentVolumeClaim... items);
  public A removeAllFromPersistentVolumeClaimResourcetemplates(Collection<PersistentVolumeClaim> items);
  public A removeMatchingFromPersistentVolumeClaimResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<A> setNewPersistentVolumeClaimResourcetemplateLike(Integer index,PersistentVolumeClaim item);
  public TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<A> addNewPersistentVolumeClaimResourcetemplate();
  public TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<A> addNewPersistentVolumeClaimResourcetemplateLike(PersistentVolumeClaim item);
  public A addToEventListenerResourcetemplates(Integer index,EventListener item);
  public A setToEventListenerResourcetemplates(Integer index,EventListener item);
  public A addToEventListenerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.EventListener... items);
  public A addAllToEventListenerResourcetemplates(Collection<EventListener> items);
  public A removeFromEventListenerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.EventListener... items);
  public A removeAllFromEventListenerResourcetemplates(Collection<EventListener> items);
  public A removeMatchingFromEventListenerResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<A> setNewEventListenerResourcetemplateLike(Integer index,EventListener item);
  public TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<A> addNewEventListenerResourcetemplate();
  public TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<A> addNewEventListenerResourcetemplateLike(EventListener item);
  public A addToTriggerResourcetemplates(Integer index,Trigger item);
  public A setToTriggerResourcetemplates(Integer index,Trigger item);
  public A addToTriggerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.Trigger... items);
  public A addAllToTriggerResourcetemplates(Collection<Trigger> items);
  public A removeFromTriggerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.Trigger... items);
  public A removeAllFromTriggerResourcetemplates(Collection<Trigger> items);
  public A removeMatchingFromTriggerResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<A> setNewTriggerResourcetemplateLike(Integer index,Trigger item);
  public TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<A> addNewTriggerResourcetemplate();
  public TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<A> addNewTriggerResourcetemplateLike(Trigger item);
  public interface ParamsNested<N> extends Nested<N>,ParamSpecFluent<TriggerTemplateSpecFluent.ParamsNested<N>>{
    public N and();
    public N endParam();
    
  }
  public interface TriggerTemplateResourcetemplatesNested<N> extends Nested<N>,TriggerTemplateFluent<TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<N>>{
    public N and();
    public N endTriggerTemplateResourcetemplate();
    
  }
  public interface ClusterInterceptorResourcetemplatesNested<N> extends Nested<N>,ClusterInterceptorFluent<TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<N>>{
    public N and();
    public N endClusterInterceptorResourcetemplate();
    
  }
  public interface TriggerBindingResourcetemplatesNested<N> extends Nested<N>,TriggerBindingFluent<TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<N>>{
    public N and();
    public N endTriggerBindingResourcetemplate();
    
  }
  public interface ClusterTriggerBindingResourcetemplatesNested<N> extends Nested<N>,ClusterTriggerBindingFluent<TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<N>>{
    public N and();
    public N endClusterTriggerBindingResourcetemplate();
    
  }
  public interface PersistentVolumeClaimResourcetemplatesNested<N> extends Nested<N>,PersistentVolumeClaimFluent<TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<N>>{
    public N and();
    public N endPersistentVolumeClaimResourcetemplate();
    
  }
  public interface EventListenerResourcetemplatesNested<N> extends Nested<N>,EventListenerFluent<TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<N>>{
    public N and();
    public N endEventListenerResourcetemplate();
    
  }
  public interface TriggerResourcetemplatesNested<N> extends Nested<N>,TriggerFluent<TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<N>>{
    public N and();
    public N endTriggerResourcetemplate();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/TriggerTemplateSpecFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimFluent;
import java.lang.String;
import java.util.function.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.HasMetadata;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimBuilder;
import io.fabric8.kubernetes.api.model.GenericKubernetesResourceBuilder;
import io.fabric8.kubernetes.api.model.GenericKubernetesResourceFluent;
import java.util.Collection;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.GenericKubernetesResource;
import java.lang.Deprecated;
import java.util.Iterator;
import java.lang.Integer;

 /**
  * Generated
  */
public interface TriggerTemplateSpecFluent<A extends TriggerTemplateSpecFluent<A>> extends Fluent<A>{
  public A addToParams(Integer index,ParamSpec item);
  public A setToParams(Integer index,ParamSpec item);
  public A addToParams(io.fabric8.tekton.triggers.v1alpha1.ParamSpec... items);
  public A addAllToParams(Collection<ParamSpec> items);
  public A removeFromParams(io.fabric8.tekton.triggers.v1alpha1.ParamSpec... items);
  public A removeAllFromParams(Collection<ParamSpec> items);
  public A removeMatchingFromParams(Predicate<ParamSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildParams instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParamSpec> getParams();
  public List<ParamSpec> buildParams();
  public ParamSpec buildParam(Integer index);
  public ParamSpec buildFirstParam();
  public ParamSpec buildLastParam();
  public ParamSpec buildMatchingParam(Predicate<ParamSpecBuilder> predicate);
  public Boolean hasMatchingParam(Predicate<ParamSpecBuilder> predicate);
  public A withParams(List<ParamSpec> params);
  public A withParams(io.fabric8.tekton.triggers.v1alpha1.ParamSpec... params);
  public Boolean hasParams();
  public A addNewParam(String _default,String description,String name);
  public TriggerTemplateSpecFluent.ParamsNested<A> addNewParam();
  public TriggerTemplateSpecFluent.ParamsNested<A> addNewParamLike(ParamSpec item);
  public TriggerTemplateSpecFluent.ParamsNested<A> setNewParamLike(Integer index,ParamSpec item);
  public TriggerTemplateSpecFluent.ParamsNested<A> editParam(Integer index);
  public TriggerTemplateSpecFluent.ParamsNested<A> editFirstParam();
  public TriggerTemplateSpecFluent.ParamsNested<A> editLastParam();
  public TriggerTemplateSpecFluent.ParamsNested<A> editMatchingParam(Predicate<ParamSpecBuilder> predicate);
  public A addToResourcetemplates(VisitableBuilder<? extends HasMetadata,?> builder);
  public A addToResourcetemplates(Integer index,VisitableBuilder<? extends HasMetadata,?> builder);
  public A addToResourcetemplates(Integer index,HasMetadata item);
  public A setToResourcetemplates(Integer index,HasMetadata item);
  public A addToResourcetemplates(io.fabric8.kubernetes.api.model.HasMetadata... items);
  public A addAllToResourcetemplates(Collection<HasMetadata> items);
  public A removeFromResourcetemplates(VisitableBuilder<? extends HasMetadata,?> builder);
  public A removeFromResourcetemplates(io.fabric8.kubernetes.api.model.HasMetadata... items);
  public A removeAllFromResourcetemplates(Collection<HasMetadata> items);
  
  /**
   * This method has been deprecated, please use method buildResourcetemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HasMetadata> getResourcetemplates();
  public List<HasMetadata> buildResourcetemplates();
  public HasMetadata buildResourcetemplate(Integer index);
  public HasMetadata buildFirstResourcetemplate();
  public HasMetadata buildLastResourcetemplate();
  public HasMetadata buildMatchingResourcetemplate(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public Boolean hasMatchingResourcetemplate(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public A withResourcetemplates(List<HasMetadata> resourcetemplates);
  public A withResourcetemplates(io.fabric8.kubernetes.api.model.HasMetadata... resourcetemplates);
  public Boolean hasResourcetemplates();
  public A addToTriggerTemplateResourcetemplates(Integer index,TriggerTemplate item);
  public A setToTriggerTemplateResourcetemplates(Integer index,TriggerTemplate item);
  public A addToTriggerTemplateResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A addAllToTriggerTemplateResourcetemplates(Collection<TriggerTemplate> items);
  public A removeFromTriggerTemplateResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerTemplate... items);
  public A removeAllFromTriggerTemplateResourcetemplates(Collection<TriggerTemplate> items);
  public A removeMatchingFromTriggerTemplateResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<A> setNewTriggerTemplateResourcetemplateLike(Integer index,TriggerTemplate item);
  public TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<A> addNewTriggerTemplateResourcetemplate();
  public TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<A> addNewTriggerTemplateResourcetemplateLike(TriggerTemplate item);
  public A addToClusterInterceptorResourcetemplates(Integer index,ClusterInterceptor item);
  public A setToClusterInterceptorResourcetemplates(Integer index,ClusterInterceptor item);
  public A addToClusterInterceptorResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A addAllToClusterInterceptorResourcetemplates(Collection<ClusterInterceptor> items);
  public A removeFromClusterInterceptorResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A removeAllFromClusterInterceptorResourcetemplates(Collection<ClusterInterceptor> items);
  public A removeMatchingFromClusterInterceptorResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<A> setNewClusterInterceptorResourcetemplateLike(Integer index,ClusterInterceptor item);
  public TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<A> addNewClusterInterceptorResourcetemplate();
  public TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<A> addNewClusterInterceptorResourcetemplateLike(ClusterInterceptor item);
  public A addToTriggerBindingResourcetemplates(Integer index,TriggerBinding item);
  public A setToTriggerBindingResourcetemplates(Integer index,TriggerBinding item);
  public A addToTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A addAllToTriggerBindingResourcetemplates(Collection<TriggerBinding> items);
  public A removeFromTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.TriggerBinding... items);
  public A removeAllFromTriggerBindingResourcetemplates(Collection<TriggerBinding> items);
  public A removeMatchingFromTriggerBindingResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<A> setNewTriggerBindingResourcetemplateLike(Integer index,TriggerBinding item);
  public TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<A> addNewTriggerBindingResourcetemplate();
  public TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<A> addNewTriggerBindingResourcetemplateLike(TriggerBinding item);
  public A addToClusterTriggerBindingResourcetemplates(Integer index,ClusterTriggerBinding item);
  public A setToClusterTriggerBindingResourcetemplates(Integer index,ClusterTriggerBinding item);
  public A addToClusterTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A addAllToClusterTriggerBindingResourcetemplates(Collection<ClusterTriggerBinding> items);
  public A removeFromClusterTriggerBindingResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.ClusterTriggerBinding... items);
  public A removeAllFromClusterTriggerBindingResourcetemplates(Collection<ClusterTriggerBinding> items);
  public A removeMatchingFromClusterTriggerBindingResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<A> setNewClusterTriggerBindingResourcetemplateLike(Integer index,ClusterTriggerBinding item);
  public TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<A> addNewClusterTriggerBindingResourcetemplate();
  public TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<A> addNewClusterTriggerBindingResourcetemplateLike(ClusterTriggerBinding item);
  public A addToPersistentVolumeClaimResourcetemplates(Integer index,PersistentVolumeClaim item);
  public A setToPersistentVolumeClaimResourcetemplates(Integer index,PersistentVolumeClaim item);
  public A addToPersistentVolumeClaimResourcetemplates(io.fabric8.kubernetes.api.model.PersistentVolumeClaim... items);
  public A addAllToPersistentVolumeClaimResourcetemplates(Collection<PersistentVolumeClaim> items);
  public A removeFromPersistentVolumeClaimResourcetemplates(io.fabric8.kubernetes.api.model.PersistentVolumeClaim... items);
  public A removeAllFromPersistentVolumeClaimResourcetemplates(Collection<PersistentVolumeClaim> items);
  public A removeMatchingFromPersistentVolumeClaimResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<A> setNewPersistentVolumeClaimResourcetemplateLike(Integer index,PersistentVolumeClaim item);
  public TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<A> addNewPersistentVolumeClaimResourcetemplate();
  public TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<A> addNewPersistentVolumeClaimResourcetemplateLike(PersistentVolumeClaim item);
  public A addToGenericKubernetesResourceResourcetemplates(Integer index,GenericKubernetesResource item);
  public A setToGenericKubernetesResourceResourcetemplates(Integer index,GenericKubernetesResource item);
  public A addToGenericKubernetesResourceResourcetemplates(io.fabric8.kubernetes.api.model.GenericKubernetesResource... items);
  public A addAllToGenericKubernetesResourceResourcetemplates(Collection<GenericKubernetesResource> items);
  public A removeFromGenericKubernetesResourceResourcetemplates(io.fabric8.kubernetes.api.model.GenericKubernetesResource... items);
  public A removeAllFromGenericKubernetesResourceResourcetemplates(Collection<GenericKubernetesResource> items);
  public A removeMatchingFromGenericKubernetesResourceResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.GenericKubernetesResourceResourcetemplatesNested<A> setNewGenericKubernetesResourceResourcetemplateLike(Integer index,GenericKubernetesResource item);
  public TriggerTemplateSpecFluent.GenericKubernetesResourceResourcetemplatesNested<A> addNewGenericKubernetesResourceResourcetemplate();
  public TriggerTemplateSpecFluent.GenericKubernetesResourceResourcetemplatesNested<A> addNewGenericKubernetesResourceResourcetemplateLike(GenericKubernetesResource item);
  public A addToEventListenerResourcetemplates(Integer index,EventListener item);
  public A setToEventListenerResourcetemplates(Integer index,EventListener item);
  public A addToEventListenerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.EventListener... items);
  public A addAllToEventListenerResourcetemplates(Collection<EventListener> items);
  public A removeFromEventListenerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.EventListener... items);
  public A removeAllFromEventListenerResourcetemplates(Collection<EventListener> items);
  public A removeMatchingFromEventListenerResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<A> setNewEventListenerResourcetemplateLike(Integer index,EventListener item);
  public TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<A> addNewEventListenerResourcetemplate();
  public TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<A> addNewEventListenerResourcetemplateLike(EventListener item);
  public A addToTriggerResourcetemplates(Integer index,Trigger item);
  public A setToTriggerResourcetemplates(Integer index,Trigger item);
  public A addToTriggerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.Trigger... items);
  public A addAllToTriggerResourcetemplates(Collection<Trigger> items);
  public A removeFromTriggerResourcetemplates(io.fabric8.tekton.triggers.v1alpha1.Trigger... items);
  public A removeAllFromTriggerResourcetemplates(Collection<Trigger> items);
  public A removeMatchingFromTriggerResourcetemplates(Predicate<VisitableBuilder<? extends HasMetadata,?>> predicate);
  public TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<A> setNewTriggerResourcetemplateLike(Integer index,Trigger item);
  public TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<A> addNewTriggerResourcetemplate();
  public TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<A> addNewTriggerResourcetemplateLike(Trigger item);
  public interface ParamsNested<N> extends Nested<N>,ParamSpecFluent<TriggerTemplateSpecFluent.ParamsNested<N>>{
    public N and();
    public N endParam();
    
  }
  public interface TriggerTemplateResourcetemplatesNested<N> extends Nested<N>,TriggerTemplateFluent<TriggerTemplateSpecFluent.TriggerTemplateResourcetemplatesNested<N>>{
    public N and();
    public N endTriggerTemplateResourcetemplate();
    
  }
  public interface ClusterInterceptorResourcetemplatesNested<N> extends Nested<N>,ClusterInterceptorFluent<TriggerTemplateSpecFluent.ClusterInterceptorResourcetemplatesNested<N>>{
    public N and();
    public N endClusterInterceptorResourcetemplate();
    
  }
  public interface TriggerBindingResourcetemplatesNested<N> extends Nested<N>,TriggerBindingFluent<TriggerTemplateSpecFluent.TriggerBindingResourcetemplatesNested<N>>{
    public N and();
    public N endTriggerBindingResourcetemplate();
    
  }
  public interface ClusterTriggerBindingResourcetemplatesNested<N> extends Nested<N>,ClusterTriggerBindingFluent<TriggerTemplateSpecFluent.ClusterTriggerBindingResourcetemplatesNested<N>>{
    public N and();
    public N endClusterTriggerBindingResourcetemplate();
    
  }
  public interface PersistentVolumeClaimResourcetemplatesNested<N> extends Nested<N>,PersistentVolumeClaimFluent<TriggerTemplateSpecFluent.PersistentVolumeClaimResourcetemplatesNested<N>>{
    public N and();
    public N endPersistentVolumeClaimResourcetemplate();
    
  }
  public interface GenericKubernetesResourceResourcetemplatesNested<N> extends Nested<N>,GenericKubernetesResourceFluent<TriggerTemplateSpecFluent.GenericKubernetesResourceResourcetemplatesNested<N>>{
    public N and();
    public N endGenericKubernetesResourceResourcetemplate();
    
  }
  public interface EventListenerResourcetemplatesNested<N> extends Nested<N>,EventListenerFluent<TriggerTemplateSpecFluent.EventListenerResourcetemplatesNested<N>>{
    public N and();
    public N endEventListenerResourcetemplate();
    
  }
  public interface TriggerResourcetemplatesNested<N> extends Nested<N>,TriggerFluent<TriggerTemplateSpecFluent.TriggerResourcetemplatesNested<N>>{
    public N and();
    public N endTriggerResourcetemplate();
    
  }
  
}
